@@ -34,62 +34,57 @@
 #' @seealso \link[=conversion]{Functions for conversion}
 #'
 #' @name tools
+#' @order 1
 #'
 NULL
 
-#' @describeIn tools Test if character object is Chinese numerals
+#' @describeIn tools Test if character object is Chinese numerals. A wrapper
+#'   around \code{\link[base]{grepl}}.
 #'
 #' @return \code{is_cnum} returns a logical vector indicating is Chinese
 #'   numerals or not for each element of \code{x}).
 #'
 #' @examples
-#' is_cnum("hello")
+#' is_cnum("yibai ershiyi")
 #'
 #' @export
 #'
 is_cnum <- function(x, lang = default_cnum_lang(), mode = "casual", financial = FALSE,
                     literal = FALSE, strict = FALSE, ...) {
   if (strict) {
-    if (length(x) > 1) {
-      return(sapply(x, function(y)
-        is_cnum(y, lang, mode, financial, literal, strict, ...)))
-    }
-    tryCatch(
-      error = function(cnd) {
-        FALSE
-      },
-      if (c2num(x, lang, mode, financial, literal)) {
-        TRUE
-      })
-  } else {
+    if (length(x) > 1)
+      return(sapply(x, function(y) is_cnum(y, lang, mode, financial, literal, strict, ...)))
+    tryCatch(as.logical(c2num(x, lang, mode, financial, literal)),
+             error = function(cnd) FALSE)
+  } else
     grepl(return_regex(lang, mode, financial, TRUE), x, ...)
-  }
 }
 
-#' @describeIn tools Test if string contains Chinese numerals
+#' @describeIn tools Test if string contains Chinese numerals. A wrapper around
+#'   \code{\link[base]{grepl}}.
 #'
 #' @return \code{has_cnum} returns a logical vector indicating contains Chinese
-#'   numerals or not for each element of \code{x}).
+#'   numerals or not for each element of \code{x}.
 #'
 #' @examples
-#' has_cnum("hello")
+#' has_cnum("yibai bashi yuan")
 #'
 #' @export
 #'
 has_cnum <- function(x, lang = default_cnum_lang(), mode = "casual", financial = FALSE, ...) {
-  if (length(x) > 1) {
+  if (length(x) > 1)
     return(sapply(x, function(y) has_cnum(y, lang, mode, financial, ...)))
-  }
   grepl(return_regex(lang, mode, financial, FALSE), x, ...)
 }
 
-#' @describeIn tools Extract Chinese numerals from string
+#' @describeIn tools Extracts Chinese numerals from string. A wrapper around
+#'   \code{\link[stringr]{str_extract_all}} from \code{stringr}.
 #'
 #' @return \code{extract_cnum} returns a list of character vectors containing
 #'   the extracted Chinese numerals.
 #'
 #' @examples
-#' extract_cnum("hello")
+#' extract_cnum("shisiyi ren")
 #'
 #' @export
 #'
